@@ -7,7 +7,7 @@ if __name__ == "__main__":
     Server.start() #starts the server
 
     while True:
-        if Server.new_data_recved: #checks if any data recved
+        if Server.event.new_data: #checks if any data recved
             data = Server.return_recved_data() #returns the recved data as a list
             for element in data:
                 client_socket, address, data = element #data is saved like this (client_socket,address,recved_data)
